import * as i0 from '@angular/core';
import { Injectable, Component, ViewChildren, ViewChild, Input, NgModule } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as pdfjsLib from 'pdfjs-dist/legacy/build/pdf';
import pdfjsWorker from 'pdfjs-dist/legacy/build/pdf.worker.entry';
import * as i1 from '@angular/common/http';
import { HttpClientModule } from '@angular/common/http';

class NgPdfViewerService {
    constructor() { }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

pdfjsLib.GlobalWorkerOptions.workerSrc = pdfjsWorker;
class NgPdfViewerComponent {
    http;
    canvasElements;
    pageContainers;
    containerElement;
    url = null;
    pdfDoc = null;
    currentPage = 1;
    scale = 1.5;
    totalPages = 0;
    pageNumbers = [];
    firstPageScale = 1;
    renderInProgress = false;
    showToolbar = true;
    showDownloadButton = true;
    fileName = null;
    // input onError
    onError = () => { };
    onLoad = () => { };
    onPageChange = () => { };
    constructor(http) {
        this.http = http;
    }
    ngOnInit() {
        if (this.url) {
            this.loadPdf();
        }
    }
    async loadPdf() {
        try {
            const response = await this.http.get(this.url, { responseType: 'arraybuffer' }).toPromise();
            const loadingTask = pdfjsLib.getDocument({ data: new Uint8Array(response) });
            this.pdfDoc = await loadingTask.promise;
            this.totalPages = this.pdfDoc.numPages;
            this.pageNumbers = Array.from({ length: this.totalPages }, (_, i) => i + 1);
            // Render pages sequentially
            for (const pageNum of this.pageNumbers) {
                await this.renderPage(pageNum);
                this.onPageChange(pageNum);
            }
            this.onLoad(this.pdfDoc);
        }
        catch (error) {
            console.error('Error loading PDF:', error);
            this.onError(error);
        }
    }
    calculateScale(page) {
        const viewport = page.getViewport({ scale: 1 }); // Get viewport at scale 1
        const container = this.containerElement.nativeElement;
        const containerWidth = container.clientWidth - 32; // Subtract padding
        return (containerWidth / viewport.width);
    }
    async renderPage(pageNum) {
        if (this.renderInProgress)
            return;
        try {
            this.renderInProgress = true;
            const page = await this.pdfDoc.getPage(pageNum);
            // Calculate scale only for first page, reuse for others
            if (pageNum === 1) {
                const initialViewport = page.getViewport({ scale: 1 });
                const container = this.containerElement.nativeElement;
                this.firstPageScale = (container.clientWidth - 32) / initialViewport.width;
            }
            // Create viewport with consistent settings
            const viewport = page.getViewport({
                scale: this.firstPageScale,
                rotation: 0,
                dontFlip: false
            });
            const canvas = this.canvasElements.get(pageNum - 1)?.nativeElement;
            if (!canvas)
                return;
            // Reset canvas completely
            canvas.width = viewport.width;
            canvas.height = viewport.height;
            if (pageNum === 1) {
                this.containerElement.nativeElement.style.setProperty('--first-page-height', `${viewport.height}px`);
            }
            const context = canvas.getContext('2d');
            const renderContext = {
                canvasContext: context,
                viewport: viewport,
                renderInteractiveForms: false,
                enableWebGL: false
            };
            // Wait for render to complete
            await page.render(renderContext).promise;
        }
        catch (error) {
            console.error(`Error rendering page ${pageNum}:`, error);
        }
        finally {
            this.renderInProgress = false;
        }
    }
    // Optional: Add navigation methods
    nextPage() {
        if (this.currentPage < this.pdfDoc.numPages) {
            this.currentPage++;
            this.renderPage(this.currentPage);
            this.scrollToPage(this.currentPage);
        }
    }
    prevPage() {
        if (this.currentPage > 1) {
            this.currentPage--;
            this.renderPage(this.currentPage);
            this.scrollToPage(this.currentPage);
        }
    }
    zoomIn() {
        this.scale *= 1.2;
        this.renderPage(this.currentPage);
    }
    zoomOut() {
        this.scale *= 0.8;
        this.renderPage(this.currentPage);
    }
    // Add resize handler
    resizeObserver = null;
    ngAfterViewInit() {
        if (this.url) {
            this.loadPdf();
        }
        // Create resize observer
        this.resizeObserver = new ResizeObserver(() => {
            if (this.pdfDoc) {
                this.pageNumbers.forEach(pageNum => this.renderPage(pageNum));
            }
        });
        // Start observing container
        if (this.containerElement) {
            this.resizeObserver.observe(this.containerElement.nativeElement);
        }
    }
    ngOnDestroy() {
        if (this.pdfDoc) {
            this.pdfDoc.destroy();
        }
        if (this.resizeObserver) {
            this.resizeObserver.disconnect();
        }
    }
    scrollToPage(pageNum) {
        setTimeout(() => {
            const pageElements = this.pageContainers.toArray();
            const container = this.containerElement.nativeElement;
            if (pageElements[pageNum - 1]) {
                const pageElement = pageElements[pageNum - 1].nativeElement;
                // Calculate scroll position
                const scrollTop = pageElement.offsetTop - container.offsetTop - 64;
                // Scroll the container
                container.scrollTo({
                    top: scrollTop,
                    behavior: 'smooth'
                });
                console.log('Scrolling to:', {
                    pageNum,
                    scrollTop,
                    pageOffset: pageElement.offsetTop,
                    containerOffset: container.offsetTop
                });
            }
        }, 0);
    }
    // Optional: Add method to jump to specific page
    goToPage(pageNum) {
        if (pageNum >= 1 && pageNum <= this.totalPages) {
            this.currentPage = pageNum;
            this.renderPage(pageNum);
            this.scrollToPage(pageNum);
        }
    }
    async downloadPdf() {
        if (!this.url)
            return;
        try {
            const response = await this.http.get(this.url, { responseType: 'blob' }).toPromise();
            const blob = new Blob([response], { type: 'application/pdf' });
            const url = window.URL.createObjectURL(blob);
            const link = document.createElement('a');
            link.href = url;
            link.download = this.getFileName();
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
            window.URL.revokeObjectURL(url);
        }
        catch (error) {
            console.error('Error downloading PDF:', error);
        }
    }
    getFileName() {
        if (this.fileName)
            return this.fileName;
        if (!this.url)
            return 'document.pdf';
        const urlParts = this.url.split('/');
        const fileName = urlParts[urlParts.length - 1];
        return fileName.includes('.pdf') ? fileName : 'document.pdf';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerComponent, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.2", type: NgPdfViewerComponent, isStandalone: true, selector: "ng-simple-pdf-viewer", inputs: { url: "url", showToolbar: ["show-toolbar", "showToolbar"], showDownloadButton: ["show-download-button", "showDownloadButton"], fileName: ["file-name", "fileName"], onError: ["on-error", "onError"], onLoad: ["on-load", "onLoad"], onPageChange: ["on-page-change", "onPageChange"] }, viewQueries: [{ propertyName: "containerElement", first: true, predicate: ["container"], descendants: true }, { propertyName: "canvasElements", predicate: ["pdfCanvas"], descendants: true }, { propertyName: "pageContainers", predicate: ["pageContainer"], descendants: true }], ngImport: i0, template: `
    <div class="document-container" #container>
      <div class="document-toolbar" *ngIf="showToolbar">
        <button class="toolbar-button" (click)="prevPage()" [disabled]="currentPage <= 1">
          <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path d="M15 18l-6-6 6-6" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
        </button>
        <span class="page-info">Page {{currentPage}} of {{totalPages}}</span>
        <button class="toolbar-button" (click)="nextPage()" [disabled]="currentPage >= totalPages">
          <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path d="M9 18l6-6-6-6" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
        </button>
        <button *ngIf="showDownloadButton" class="toolbar-button" (click)="downloadPdf()" title="Download PDF">
          <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
            <path d="M7 10l5 5 5-5" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
            <path d="M12 15V3" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
        </button>
      </div>
      <div *ngFor="let pageNum of pageNumbers" class="document-page" #pageContainer>
        <canvas #pdfCanvas></canvas>
      </div>
    </div>
  `, isInline: true, styles: [":host{display:block;width:100%}.document-container{position:relative;scroll-behavior:smooth;scroll-padding-top:4rem;width:calc(100% - 2rem);height:var(--first-page-height, auto);max-height:100vh;overflow-y:auto;padding:0 1rem;background-color:#f0f0f0}.document-page{position:relative;scroll-margin-top:4rem;margin:1rem 0;display:flex;justify-content:center}canvas{width:100%;height:auto;border-radius:.25rem}.document-toolbar{position:sticky;top:1rem;z-index:100;display:flex;align-items:center;justify-content:center;gap:1rem;background:#fff;padding:.1rem;border-radius:8px;box-shadow:0 2px 8px #0000001a;width:fit-content;margin:0 auto;-webkit-backdrop-filter:blur(8px);backdrop-filter:blur(8px);background-color:#ffffffe6}.toolbar-button{display:flex;align-items:center;justify-content:center;border:none;background:transparent;padding:.5rem;border-radius:6px;cursor:pointer;color:#666;transition:all .2s ease}.toolbar-button:hover:not(:disabled){background-color:#0000000d;color:#333}.toolbar-button:disabled{opacity:.5;cursor:not-allowed}.page-info{font-size:.9rem;color:#666;min-width:100px;text-align:center}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-simple-pdf-viewer', template: `
    <div class="document-container" #container>
      <div class="document-toolbar" *ngIf="showToolbar">
        <button class="toolbar-button" (click)="prevPage()" [disabled]="currentPage <= 1">
          <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path d="M15 18l-6-6 6-6" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
        </button>
        <span class="page-info">Page {{currentPage}} of {{totalPages}}</span>
        <button class="toolbar-button" (click)="nextPage()" [disabled]="currentPage >= totalPages">
          <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path d="M9 18l6-6-6-6" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
        </button>
        <button *ngIf="showDownloadButton" class="toolbar-button" (click)="downloadPdf()" title="Download PDF">
          <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
            <path d="M7 10l5 5 5-5" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
            <path d="M12 15V3" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
        </button>
      </div>
      <div *ngFor="let pageNum of pageNumbers" class="document-page" #pageContainer>
        <canvas #pdfCanvas></canvas>
      </div>
    </div>
  `, standalone: true, imports: [CommonModule], styles: [":host{display:block;width:100%}.document-container{position:relative;scroll-behavior:smooth;scroll-padding-top:4rem;width:calc(100% - 2rem);height:var(--first-page-height, auto);max-height:100vh;overflow-y:auto;padding:0 1rem;background-color:#f0f0f0}.document-page{position:relative;scroll-margin-top:4rem;margin:1rem 0;display:flex;justify-content:center}canvas{width:100%;height:auto;border-radius:.25rem}.document-toolbar{position:sticky;top:1rem;z-index:100;display:flex;align-items:center;justify-content:center;gap:1rem;background:#fff;padding:.1rem;border-radius:8px;box-shadow:0 2px 8px #0000001a;width:fit-content;margin:0 auto;-webkit-backdrop-filter:blur(8px);backdrop-filter:blur(8px);background-color:#ffffffe6}.toolbar-button{display:flex;align-items:center;justify-content:center;border:none;background:transparent;padding:.5rem;border-radius:6px;cursor:pointer;color:#666;transition:all .2s ease}.toolbar-button:hover:not(:disabled){background-color:#0000000d;color:#333}.toolbar-button:disabled{opacity:.5;cursor:not-allowed}.page-info{font-size:.9rem;color:#666;min-width:100px;text-align:center}\n"] }]
        }], ctorParameters: () => [{ type: i1.HttpClient }], propDecorators: { canvasElements: [{
                type: ViewChildren,
                args: ['pdfCanvas']
            }], pageContainers: [{
                type: ViewChildren,
                args: ['pageContainer']
            }], containerElement: [{
                type: ViewChild,
                args: ['container']
            }], url: [{
                type: Input
            }], showToolbar: [{
                type: Input,
                args: ['show-toolbar']
            }], showDownloadButton: [{
                type: Input,
                args: ['show-download-button']
            }], fileName: [{
                type: Input,
                args: ['file-name']
            }], onError: [{
                type: Input,
                args: ['on-error']
            }], onLoad: [{
                type: Input,
                args: ['on-load']
            }], onPageChange: [{
                type: Input,
                args: ['on-page-change']
            }] } });

class NgPdfViewerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerModule, imports: [CommonModule,
            HttpClientModule,
            NgPdfViewerComponent], exports: [NgPdfViewerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerModule, imports: [CommonModule,
            HttpClientModule,
            NgPdfViewerComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.2", ngImport: i0, type: NgPdfViewerModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        HttpClientModule,
                        NgPdfViewerComponent
                    ],
                    exports: [NgPdfViewerComponent]
                }]
        }] });

/*
 * Public API Surface of ng-simple-pdf-viewer
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgPdfViewerComponent, NgPdfViewerModule, NgPdfViewerService };
//# sourceMappingURL=ng-simple-pdf-viewer.mjs.map
